@@ -1,6 +1,6 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	$Id: mhexternal.pl,v 2.12 2002/10/11 01:57:53 ehood Exp $
+##	$Id: mhexternal.pl,v 2.17 2003/08/07 05:49:47 ehood Exp $
 ##  Author:
 ##      Earl Hood       mhonarc@mhonarc.org
 ##  Description:
@@ -105,13 +105,12 @@ package m2h_external;
 ##
 sub filter {
     my($fields, $data, $isdecode, $args) = @_;
-    my($ret, $filename, $urlfile, $disp);
+    my($ret, $filename, $urlfile);
     require 'mhmimetypes.pl';
 
     ## Init variables
     $args	   = ''  unless defined($args);
     my $name	   = '';
-    my $nameparm   = '';
     my $ctype	   = '';
     my $type	   = '';
     my $ext	   = '';
@@ -137,12 +136,15 @@ sub filter {
     }
 
     ## Get content-type
-    ($ctype) = $fields->{'content-type'}[0] =~ m%^\s*([\w\-\./]+)%;
-    $ctype =~ tr/A-Z/a-z/;
+    if (!defined($ctype = $fields->{'x-mha-content-type'})) {
+	($ctype) = $fields->{'content-type'}[0] =~ m%^\s*([\w\-\./]+)%;
+	$ctype =~ tr/A-Z/a-z/;
+    }
     $type = (mhonarc::get_mime_ext($ctype))[1];
 
     ## Get disposition
-    ($disp, $nameparm) = readmail::MAILhead_get_disposition($fields);
+    my($disp, $nameparm, $raw_name, $html_name) =
+	readmail::MAILhead_get_disposition($fields, 1);
     $name = $nameparm  if $usename;
     &debug("Content-type: $ctype",
 	   "Disposition: $disp; filename=$nameparm",
@@ -157,7 +159,7 @@ sub filter {
 
     ## Check if content is excluded based on filename extension
     if ($excexts && index($excexts, ",$dispext,") >= $[) {
-      return (qq|<p><tt>&lt&lt;attachment: |.
+      return (qq|<p><tt>&lt;&lt;attachment: |.
 	      mhonarc::htmlize($nameparm).
 	      qq|&gt;&gt;</tt></p>\n|);
     }
@@ -199,8 +201,10 @@ sub filter {
     $target = qq/ TARGET="$target"/  if $target;
 
     ## Write file
-    $filename = mhonarc::write_attachment($ctype, $data, $path, $name, $inext);
-    ($urlfile = $filename) =~ s/([^\w.\-\/])/sprintf("%%%X",unpack("C",$1))/ge;
+    $filename =
+	mhonarc::write_attachment($ctype, $data, $path, $name, $inext);
+    ($urlfile = $filename) =~
+	s/([^\w.\-\/])/sprintf("%%%X",unpack("C",$1))/ge;
     &debug("File-written: $filename")  if $debug;
 
     ## Check if inlining when CT not image/*
@@ -229,12 +233,22 @@ sub filter {
 	my $namelabel;
 
 	if ($is_mesg && ($$data =~ /^subject:\s(.+)$/mi)) {
-	    $namelabel = mhonarc::htmlize($1);
+	    #$namelabel = mhonarc::htmlize($1);
+	    $namelabel = readmail::MAILdecode_1522_str($1);
 	    $desc .= 'Message attachment';
 	} else {
 	    $desc .= mhonarc::htmlize($fields->{'content-description'}[0]) ||
 		     $type;
-	    $namelabel = mhonarc::htmlize($nameparm || $urlfile);
+	    if ($nameparm) {
+		#$namelabel = mhonarc::htmlize($nameparm);
+		$namelabel = $html_name;
+	    } elsif ($filename) {
+		$namelabel = $filename;
+		$namelabel =~ s/^.*$mhonarc::DIRSEPREX//o;
+		mhonarc::htmlize(\$namelabel);
+	    } else {
+		$namelabel = $ctype;
+	    }
 	}
 
 	# check if using icon
